* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF; ODS LISTING;

***********************************************************************************;
*******             BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE           *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
%LET filesave= C:\Dropbox\14_SPLH861\861_Example3;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";

* Import chapter 2 example data into work library;
DATA work.Chapter2; SET filesave.SAS_Chapter2;
* Center continuous predictors;
age85 = age - 85;
grip9 = grip - 9;
* Creating all possible contrasts for dementia groups;
     IF demgroup=1 THEN DO; demNF=0; demNC=0; END;
ELSE IF demgroup=2 THEN DO; demNF=1; demNC=0; END;
ELSE IF demgroup=3 THEN DO; demNF=0; demNC=1; END;
* Labeling new variables;
LABEL   
age85=  "age85: Age in Years (0=85)"
grip9=  "grip9: Grip Strength in Pounds (0=9)"
demNF=  "demNF: Dementia Contrast for None=0 vs Future=1"
demNC=  "demNC: Dementia Contrast for None=0 vs Current=1";
RUN;

***********************************************************************************;
*******                       BEGIN EXAMPLE 3 MODELS                        *******;
***********************************************************************************;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example3_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 'Eq 2.3: Empty Means Model';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition =  / SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovEmpty; * Needed to compare with later;
RUN; TITLE1;

TITLE1 'Eq 2.8: Adding Dementia Group';
TITLE2 'Using Manual Group Contrasts so Reference=None';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 sexMW demNF demNC / CHISQ SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovDem;
	 CONTRAST "Model R2 F-Test" age85 1, grip9 1, sexmw 1, demNF 1, demNC 1 / CHISQ;
     CONTRAST "Omnibus F-Test for Dementia Group" demNF 1, demNC 1 / CHISQ;
     * Request group means (hold age=85, grip=9, men);
     ESTIMATE "Intercept for None Group"    intercept 1 demNF 0 demNC 0 / CL;
     ESTIMATE "Intercept for Future Group"  intercept 1 demNF 1 demNC 0 / CL;
     ESTIMATE "Intercept for Current Group" intercept 1 demNF 0 demNC 1 / CL;
     * Request group differences;
     ESTIMATE "None   vs. Future Group"   demNF  1 demNC 0 / CL;
     ESTIMATE "None   vs. Current Group"  demNF  0 demNC 1 / CL;
     ESTIMATE "Future vs. Current Group"  demNF -1 demNC 1 / CL;
RUN; TITLE1; TITLE2;

TITLE1 'Eq 2.8: Adding Dementia Group';
TITLE2 'Categorical Predictor for Dementia Group';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     CLASS demgroup;
     MODEL cognition = age85 grip9 sexMW demgroup / SOLUTION CL DDFM=BW;
     LSMEANS demgroup / DIFF=ALL CL AT(age85 grip9 sexMW) = (0 0 0);
RUN; TITLE1; TITLE2;

TITLE1 'Eq 2.16: Adding Sex by Dementia Interaction';
TITLE2 'Categorical Sex and Dementia';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     CLASS sexMW demgroup;
     MODEL cognition = age85 grip9 sexMW demgroup
                       age85*grip9 sexMW*demgroup / CHISQ SOLUTION CL DDFM=BW;
	 LSMEANS sexMW    / DIFF=ALL CL AT(age85 grip9) = (0 0);
	 LSMEANS demgroup / DIFF=ALL CL AT(age85 grip9) = (0 0);
     LSMEANS sexMW*demgroup / SLICE=demgroup SLICE=sexMW DIFF=ALL CL AT(age85 grip9) = (0 0);
	 * Order by CLASS statement: MN MF MC WN WF WC -- check order with / E;
	 CONTRAST "A: Sex Effect differ between None and Future?"    sexMW*demgroup -1  1  0  1 -1  0 / CHISQ;
	 CONTRAST "A: None-Future Effect differ by Sex?"             sexMW*demgroup -1  1  0  1 -1  0 / CHISQ;
	 CONTRAST "B: Sex Effect differ between None and Current?"   sexMW*demgroup -1  0  1  1  0 -1 / CHISQ;
	 CONTRAST "B: None-Current Effect differ by Sex?"            sexMW*demgroup -1  0  1  1  0 -1 / CHISQ;
	 CONTRAST "C: Sex Effect differ between Future and Current?" sexMW*demgroup  0 -1  1  0  1 -1 / CHISQ;
	 CONTRAST "C: Future-Current Effect differ by Sex?"          sexMW*demgroup  0 -1  1  0  1 -1 / CHISQ;
	 * Getting actual differences of differences;
	 ESTIMATE "A: Sex Effect differ between None and Future?"    sexMW*demgroup -1  1  0  1 -1  0;
	 ESTIMATE "A: None-Future Effect differ by Sex?"             sexMW*demgroup -1  1  0  1 -1  0;
	 ESTIMATE "B: Sex Effect differ between None and Current?"   sexMW*demgroup -1  0  1  1  0 -1;
	 ESTIMATE "B: None-Current Effect differ by Sex?"            sexMW*demgroup -1  0  1  1  0 -1;
	 ESTIMATE "C: Sex Effect differ between Future and Current?" sexMW*demgroup  0 -1  1  0  1 -1;
	 ESTIMATE "C: Future-Current Effect differ by Sex?"          sexMW*demgroup  0 -1  1  0  1 -1;
RUN; TITLE1; TITLE2;

* Close output;
ODS RTF CLOSE;
